=======
Credits
=======

Development Lead
----------------

* Saket Choudhary <saketkc@gmail.com>

Contributors
------------

* `Dibya Gautam <https://github.com/dibyaaaaax>`_
* `Marius van den Beek <https://github.com/mvdbeek>`_
